/**
 * This specification defines four features of the window object. It describes the use of the Window object as a browsing context: a container that displays a document, or a series of documents in sequence. It describes interfaces for navigation, the ability to go to a new document in the same browsing context. It describes interfaces for embedding, a feature also known as compound document by reference, where one document includes another separate document by external reference. And it specifies methods for using timers.
 */
var Window = {};
}
/**
 * The value of the window attribute MUST be the same Window object that has the attribute: the attribute is a self-reference.
 * @returns {Window} 
 */
Window.prototype.window;

/**
 * The value of the location attribute MUST be the Location object that represents the window's current location.
 * @returns {Location} 
 */
Window.prototype.location;

/**
 * This method calls the function once after a specified number of milliseconds elapses, until canceled by a call to clearTimeout. The methods returns a timerID which may be used in a subsequent call to clearTimeout to cancel the interval.
 * @param {Function} listener Function to be called.
 * @param {Number} milliseconds interval
 * @returns {Number} 
 */
Window.prototype.setTimeout = function() {};

/**
 * Cancels an interval that was set with the setTimeout method.
 * @param {Number} intervalID Identified of the interval.
 * @returns {undefined} 
 */
Window.prototype.clearInterval = function() {};

/**
 * An attribute containing a unique name used to refer to this Window object. 
 * @returns {DOMString} 
 */
Window.prototype.name;

/**
 * @returns {Element} 
 */
Window.prototype.frameElement;

/**
 * An attribute containing a reference to Window object that contains this object.
 * @returns {Window} 
 */
Window.prototype.parent;

/**
 * Cancels a timeout that was set with the setTimeout method.
 * @param {Number} timerID Identified of the timer.
 * @returns {undefined} 
 */
Window.prototype.clearTimeout = function() {};

/**
 * The value of the self attribute MUST be the same Window object that has the attribute: the attribute is a self-reference. Consequently, the value of the self attribute MUST be the same object as the window attribute.
 * @returns {Window} 
 */
Window.prototype.self;

/**
 * This method calls the function every time a specified number of milliseconds elapses, until canceled by a call to clearInterval. The methods returns an intervalID which may be used in a subsequent call to clearInterval to cancel the interval.
 * @param {Function} listener Function to be called.
 * @param {Number} milliseconds interval
 * @returns {Number} 
 */
Window.prototype.setInterval = function() {};

/**
 * An attribute containing a reference to the topmost Window object in the hierarchy that contains this object.
 * @returns {Window} 
 */
Window.prototype.top;

/**
 * Represents the Window prototype object.
 * @syntax Window.prototype
 * @static
 */
Window.prototype = new AbstractView();

